"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class AddressType(str, Enum):
    r"""The type of the address"""
    UNKNOWN = 'Unknown'
    BILLING = 'Billing'
    DELIVERY = 'Delivery'
