"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class SalesOrderInvoiceStatus(str, Enum):
    r"""If the sales order is converted to an invoice, or will be in future, the invoicingStatus field indicates the current stage of the invoicing process."""
    UNKNOWN = 'Unknown'
    PARTIALLY_INVOICED = 'PartiallyInvoiced'
    INVOICED = 'Invoiced'
    NOT_INVOICED = 'NotInvoiced'
