"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class CreditNoteStatus(str, Enum):
    UNKNOWN = 'Unknown'
    DRAFT = 'Draft'
    SUBMITTED = 'Submitted'
    PAID = 'Paid'
    VOID = 'Void'
    PARTIALLY_PAID = 'PartiallyPaid'
