"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class ReportBasis(str, Enum):
    r"""Accounting method used when aggregating the report data. In this case, `Cash`."""
    UNKNOWN = 'Unknown'
    ACCRUAL = 'Accrual'
    CASH = 'Cash'
