"""Code generated by Speakeasy (https://speakeasyapi.dev). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum

class BilledToType1(str, Enum):
    UNKNOWN = 'Unknown'
    NOT_APPLICABLE = 'NotApplicable'
    PROJECT = 'Project'
